summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_sheet.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kspread/kspread_sheet.cc
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kspread/kspread_sheet.cc')
-rw-r--r--kspread/kspread_sheet.cc42
1 files changed, 21 insertions, 21 deletions
diff --git a/kspread/kspread_sheet.cc b/kspread/kspread_sheet.cc
index 0e7f7bcc..a888a392 100644
--- a/kspread/kspread_sheet.cc
+++ b/kspread/kspread_sheet.cc
@@ -151,7 +151,7 @@ void ChartBinding::cellChanged( Cell* /*changedCell*/ )
//Ensure display gets updated by marking all cells underneath the chart as
//dirty
- const TQRect chartGeometry = m_child->tqgeometry().toTQRect();
+ const TQRect chartGeometry = m_child->geometry().toTQRect();
double tmp;
int left = sheet()->leftColumn( chartGeometry.left() , tmp );
@@ -201,7 +201,7 @@ void ChartBinding::cellChanged( Cell* /*changedCell*/ )
// Force a redraw of the chart on all views
/** TODO - replace the call below with something that will tqrepaint this chart */
#endif
// sheet()->emit_polygonInvalidated( m_child->framePointArray() );
}
@@ -1819,7 +1819,7 @@ struct SetSelectionFirstLetterUpperWorker : public Sheet::CellWorker
cell->setDisplayDirtyFlag();
TQString tmp = cell->text();
int len = tmp.length();
- cell->setCellText( (tmp.tqat(0).upper()+tmp.right(len-1)) );
+ cell->setCellText( (tmp.at(0).upper()+tmp.right(len-1)) );
cell->clearDisplayDirtyFlag();
}
};
@@ -6129,7 +6129,7 @@ KoRect Sheet::getRealRect( bool all )
{
if ( all || ( it.current()->isSelected() && ! it.current()->isProtect() ) )
- rect |= it.current()->tqgeometry();
+ rect |= it.current()->geometry();
}
return rect;
@@ -6149,12 +6149,12 @@ KCommand *Sheet::moveObject(View *_view, double diffx, double diffy)
if ( it.current()->isSelected() && !it.current()->isProtect())
{
_objects.append( it.current() );
- KoRect tqgeometry = it.current()->tqgeometry();
- tqgeometry.moveBy( -canvas->xOffset(), -canvas->yOffset() );
- TQRect br = doc()->zoomRect( tqgeometry/*it.current()->tqgeometry()*/ );
+ KoRect geometry = it.current()->geometry();
+ geometry.moveBy( -canvas->xOffset(), -canvas->yOffset() );
+ TQRect br = doc()->zoomRect( geometry/*it.current()->geometry()*/ );
br.moveBy( doc()->zoomItX( diffx ), doc()->zoomItY( diffy ) );
br.moveBy( doc()->zoomItX( -canvas->xOffset() ), doc()->zoomItY( -canvas->yOffset() ) );
- canvas->tqrepaint( br ); // Previous position
+ canvas->repaint( br ); // Previous position
canvas->repaintObject( it.current() ); // New position
createCommand=true;
}
@@ -6179,18 +6179,18 @@ KCommand *Sheet::moveObject(View *_view,const KoPoint &_move,bool key)
{
if ( it.current()->isSelected() && !it.current()->isProtect()) {
- KoRect tqgeometry = it.current()->tqgeometry();
- tqgeometry.moveBy( -canvas->xOffset(), -canvas->yOffset() );
- TQRect oldBoundingRect = doc()->zoomRect( tqgeometry );
+ KoRect geometry = it.current()->geometry();
+ geometry.moveBy( -canvas->xOffset(), -canvas->yOffset() );
+ TQRect oldBoundingRect = doc()->zoomRect( geometry );
- KoRect r = it.current()->tqgeometry();
+ KoRect r = it.current()->geometry();
r.moveBy( _move.x(), _move.y() );
it.current()->setGeometry( r );
_objects.append( it.current() );
- canvas->tqrepaint( oldBoundingRect );
+ canvas->repaint( oldBoundingRect );
canvas->repaintObject( it.current() );
}
}
@@ -6235,7 +6235,7 @@ void Sheet::unifyObjectName( EmbeddedObject *object ) {
if ( rx.search( objectName ) != -1 ) {
objectName.remove( rx );
}
- objectName += TQString(" (%1)").tqarg( count );
+ objectName += TQString(" (%1)").arg( count );
object->setObjectName( objectName );
}
}
@@ -6479,7 +6479,7 @@ bool Sheet::loadOasis( const TQDomElement& sheetElement, KoOasisLoadingContext&
loadRowFormat( rowElement, rowIndex, oasisContext, /*rowNode.isNull() ,*/ styleMap );
kdDebug()<<" table-row found :index row after "<<rowIndex<<endl;
}
- else if ( rowElement.localName() == "tqshapes" )
+ else if ( rowElement.localName() == "shapes" )
loadOasisObjects( rowElement, oasisContext );
}
}
@@ -6685,7 +6685,7 @@ void Sheet::loadOasisMasterLayoutPage( KoStyleStack &styleStack )
kdDebug()<<" table-centering unknown :"<<str<<endl;
#endif
}
- format = TQString( "%1x%2" ).tqarg( width ).tqarg( height );
+ format = TQString( "%1x%2" ).arg( width ).arg( height );
kdDebug()<<" format : "<<format<<endl;
d->print->setPaperLayout( left, top, right, bottom, format, orientation );
@@ -8071,7 +8071,7 @@ void Sheet::updateCell( Cell */*cell*/, int _column, int _row )
updateCellArea(cellArea);
}
-void Sheet::emit_updateRow( RowFormat *_format, int _row, bool tqrepaint )
+void Sheet::emit_updateRow( RowFormat *_format, int _row, bool repaint )
{
if ( doc()->isLoading() )
return;
@@ -8081,7 +8081,7 @@ void Sheet::emit_updateRow( RowFormat *_format, int _row, bool tqrepaint )
if ( c->row() == _row )
c->setLayoutDirtyFlag( true );
- if ( tqrepaint )
+ if ( repaint )
{
//All the cells in this row, or below this row will need to be repainted
//So add that region of the sheet to the paint dirty list.
@@ -8256,7 +8256,7 @@ bool Sheet::saveChildren( KoStore* _store, const TQString &_path )
{
if ( it.current()->sheet() == this && ( it.current()->getType() == OBJECT_KOFFICE_PART || it.current()->getType() == OBJECT_CHART ) )
{
- TQString path = TQString( "%1/%2" ).tqarg( _path ).tqarg( i++ );
+ TQString path = TQString( "%1/%2" ).arg( _path ).arg( i++ );
if ( !dynamic_cast<EmbeddedKOfficeObject*>( it.current() )->embeddedObject()->document()->saveToStore( _store, path ) )
return false;
}
@@ -8279,7 +8279,7 @@ bool Sheet::saveOasisObjects( KoStore */*store*/, KoXmlWriter &xmlWriter, KoGenS
{
if ( !objectFound )
{
- xmlWriter.startElement( "table:tqshapes" );
+ xmlWriter.startElement( "table:shapes" );
objectFound = true;
}
if ( !it.current()->saveOasisObject(sc) )
@@ -8565,7 +8565,7 @@ void Sheet::printDebug()
cellDescr += " | ";
cellDescr += cell->text();
if ( cell->isFormula() )
- cellDescr += TQString(" [result: %1]").tqarg( cell->value().asString() );
+ cellDescr += TQString(" [result: %1]").arg( cell->value().asString() );
kdDebug(36001) << cellDescr << endl;
}
}
@@ -201,7 +201,7 @@ void ChartBinding::cellChanged( Cell* /*changedCell*/ )
// Force a redraw of the chart on all views
- /** TODO - replace the call below with something that will tqrepaint this chart */
+ /** TODO - replace the call below with something that will repaint this chart */
#endif
// sheet()->emit_polygonInvalidated( m_child->framePointArray() );